@@ -23,7 +23,11 @@
 */
 
 #include <config.h>
+#ifdef GNOME_GTKHTML_EDITOR_SHLIB
+#include <glib/gi18n-lib.h>
+#else
 #include <glib/gi18n.h>
+#endif
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <fcntl.h>
@@ -36,6 +40,12 @@
 #include "persist-file.h"
 #include "editor-control-factory.h"
 
+#include <glib/gstdio.h>
+
+#ifndef O_BINARY
+#define O_BINARY 0
+#endif
+
 static BonoboObjectClass *gtk_html_persist_file_parent_class;
 
 static void impl_save (PortableServer_Servant servant, const CORBA_char *path, CORBA_Environment * ev);
@@ -140,7 +150,7 @@ impl_load (PortableServer_Servant servant, const CORBA_char *path, CORBA_Environ
 	gboolean was_editable;
 	int fd;
 
-	fd = open (path, O_RDONLY);
+	fd = g_open (path, O_RDONLY | O_BINARY, 0);
 	if (fd == -1)
 		return;
 
@@ -211,7 +221,7 @@ impl_save (PortableServer_Servant servant, const CORBA_char *path, CORBA_Environ
 	GtkHTMLPersistFile *file = GTK_HTML_PERSIST_FILE (bonobo_object_from_servant (servant));
 	int fd;
 
-	fd = open (path, O_WRONLY | O_CREAT | O_TRUNC, 0666);
+	fd = g_open (path, O_WRONLY | O_CREAT | O_TRUNC | O_BINARY, 0666);
 
 	if (fd == -1)
 		return;
