@@ -29,10 +29,11 @@
 #else
 #include <glib/gi18n.h>
 #endif
-#include <gnome.h>
+#include <libgnomeui/gnome-app-helper.h>
 #include <bonobo.h>
 
 #include "gi-color-combo.h"
+#include "paragraph-style.h"
 #include "toolbar.h"
 #include "utils.h"
 #include "htmlcolor.h"
@@ -43,183 +44,68 @@
 
 #define EDITOR_TOOLBAR_PATH "/HTMLEditor"
 
-
-/* Paragraph style option menu.  */
-
-static struct {
-	GtkHTMLParagraphStyle style;
-	const gchar *description;
-} paragraph_style_items[] = {
-	{ GTK_HTML_PARAGRAPH_STYLE_NORMAL, N_("Normal") },
-	{ GTK_HTML_PARAGRAPH_STYLE_PRE, N_("Preformat") },
-	{ GTK_HTML_PARAGRAPH_STYLE_ITEMDOTTED, N_("Bulleted List") },
-	{ GTK_HTML_PARAGRAPH_STYLE_ITEMDIGIT, N_("Numbered List") },
-	{ GTK_HTML_PARAGRAPH_STYLE_ITEMROMAN, N_("Roman List") },
-	{ GTK_HTML_PARAGRAPH_STYLE_ITEMALPHA, N_("Alphabetical List") },
-	{ GTK_HTML_PARAGRAPH_STYLE_H1, N_("Header 1") },
-	{ GTK_HTML_PARAGRAPH_STYLE_H2, N_("Header 2") },
-	{ GTK_HTML_PARAGRAPH_STYLE_H3, N_("Header 3") },
-	{ GTK_HTML_PARAGRAPH_STYLE_H4, N_("Header 4") },
-	{ GTK_HTML_PARAGRAPH_STYLE_H5, N_("Header 5") },
-	{ GTK_HTML_PARAGRAPH_STYLE_H6, N_("Header 6") },
-	{ GTK_HTML_PARAGRAPH_STYLE_ADDRESS, N_("Address") },
-	{ GTK_HTML_PARAGRAPH_STYLE_NORMAL, NULL },
-};
-
 static void
-paragraph_style_changed_cb (GtkHTML *html,
-			    GtkHTMLParagraphStyle style,
-			    gpointer data)
+active_font_size_changed (GtkComboBox *combo_box,
+                          GtkHTMLControlData *cd)
 {
-	GtkOptionMenu *option_menu;
-	guint i;
+	GtkHTMLFontStyle style = GTK_HTML_FONT_STYLE_SIZE_1;
 
-	option_menu = GTK_OPTION_MENU (data);
-
-	for (i = 0; paragraph_style_items[i].description != NULL; i++) {
-		if (paragraph_style_items[i].style == style) {
-			gtk_option_menu_set_history (option_menu, i);
-			return;
-		}
-	}
-
-	g_warning ("Editor component toolbar: unknown paragraph style %d", style);
-}
-
-static void
-paragraph_style_menu_item_activated_cb (GtkWidget *widget,
-					gpointer data)
-{
-	GtkHTMLParagraphStyle style;
-	GtkHTML *html;
-
-	html = GTK_HTML (data);
-	style = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (widget), "paragraph_style_value"));
-
-	/* g_warning ("Setting paragraph style to %d.", style); */
-
-	gtk_html_set_paragraph_style (html, style);
-}
-
-static void
-paragraph_style_menu_item_update (GtkWidget *widget, gpointer format_html)
-{
-	GtkHTMLParagraphStyle style;
-	gint sensitive;
-
-	style = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (widget), "paragraph_style_value"));
-	
-	sensitive = (format_html
-		     || style == GTK_HTML_PARAGRAPH_STYLE_NORMAL
-		     || style == GTK_HTML_PARAGRAPH_STYLE_PRE
-		     || style == GTK_HTML_PARAGRAPH_STYLE_ITEMDOTTED
-		     || style == GTK_HTML_PARAGRAPH_STYLE_ITEMROMAN
-		     || style == GTK_HTML_PARAGRAPH_STYLE_ITEMDIGIT
-		     || style == GTK_HTML_PARAGRAPH_STYLE_ITEMALPHA
-		     );
-
-	gtk_widget_set_sensitive (widget, sensitive);	
-}
-
-static void
-paragraph_style_option_menu_set_mode (GtkWidget *option_menu, gboolean format_html)
-{
-	GtkWidget *menu;
-	
-	menu = gtk_option_menu_get_menu (GTK_OPTION_MENU (option_menu));
-	gtk_container_forall (GTK_CONTAINER (menu), 
-			      paragraph_style_menu_item_update, 
-			      GINT_TO_POINTER (format_html));
-}
-
-static GtkWidget *
-setup_paragraph_style_option_menu (GtkHTML *html)
-{
-	GtkWidget *option_menu;
-	GtkWidget *menu;
-	guint i;
-
-	option_menu = gtk_option_menu_new ();
-	menu = gtk_menu_new ();
-
-	for (i = 0; paragraph_style_items[i].description != NULL; i++) {
-		GtkWidget *menu_item;
-
-		menu_item = gtk_menu_item_new_with_label (_(paragraph_style_items[i].description));
-		gtk_widget_show (menu_item);
-
-		gtk_menu_shell_append (GTK_MENU_SHELL (menu), menu_item);
-
-		g_object_set_data (G_OBJECT (menu_item), "paragraph_style_value",
-				     GINT_TO_POINTER (paragraph_style_items[i].style));
-		g_signal_connect (menu_item, "activate", G_CALLBACK (paragraph_style_menu_item_activated_cb), html);
-	}
-
-	gtk_option_menu_set_menu (GTK_OPTION_MENU (option_menu), menu);
-	g_signal_connect (html, "current_paragraph_style_changed", G_CALLBACK (paragraph_style_changed_cb), option_menu);
-	gtk_widget_show (option_menu);
-
-	return option_menu;
-}
-
-static void
-set_font_size (GtkWidget *w, GtkHTMLControlData *cd)
-{
-	GtkHTMLFontStyle style = GTK_HTML_FONT_STYLE_SIZE_1 + GPOINTER_TO_INT (g_object_get_data (G_OBJECT (w),
-												    "size"));
+	style += gtk_combo_box_get_active (combo_box);
 
 	if (!cd->block_font_style_change)
-		gtk_html_set_font_style (cd->html, GTK_HTML_FONT_STYLE_MAX & ~GTK_HTML_FONT_STYLE_SIZE_MASK, style);
+		gtk_html_set_font_style (cd->html,
+			GTK_HTML_FONT_STYLE_MAX &
+			~GTK_HTML_FONT_STYLE_SIZE_MASK,
+			style);
 }
 
 static void
-font_size_changed (GtkWidget *w, GtkHTMLParagraphStyle style, GtkHTMLControlData *cd)
+font_size_changed (GtkHTML *html,
+                   GtkHTMLFontStyle style,
+                   GtkHTMLControlData *cd)
 {
 	if (style == GTK_HTML_FONT_STYLE_DEFAULT)
 		style = GTK_HTML_FONT_STYLE_SIZE_3;
+	else
+		style &= GTK_HTML_FONT_STYLE_SIZE_MASK;
+
 	cd->block_font_style_change++;
-	gtk_option_menu_set_history (GTK_OPTION_MENU (cd->font_size_menu),
-				     (style & GTK_HTML_FONT_STYLE_SIZE_MASK) - GTK_HTML_FONT_STYLE_SIZE_1);
+
+	gtk_combo_box_set_active (
+		GTK_COMBO_BOX (cd->font_size_menu),
+		style - GTK_HTML_FONT_STYLE_SIZE_1);
+
 	cd->block_font_style_change--;
 }
 
 static GtkWidget *
-setup_font_size_option_menu (GtkHTMLControlData *cd)
+setup_font_size_combo_box (GtkHTMLControlData *cd)
 {
-	GtkWidget *option_menu;
-	GtkWidget *menu;
-	guint i;
-	gchar size [3];
+	GtkWidget *combo_box;
 
-	cd->font_size_menu = option_menu = gtk_option_menu_new ();
+	combo_box = gtk_combo_box_new_text ();
 
-	menu = gtk_menu_new ();
-	size [2] = 0;
+	gtk_combo_box_append_text (GTK_COMBO_BOX (combo_box), "-2");
+	gtk_combo_box_append_text (GTK_COMBO_BOX (combo_box), "-1");
+	gtk_combo_box_append_text (GTK_COMBO_BOX (combo_box), "+0");
+	gtk_combo_box_append_text (GTK_COMBO_BOX (combo_box), "+1");
+	gtk_combo_box_append_text (GTK_COMBO_BOX (combo_box), "+2");
+	gtk_combo_box_append_text (GTK_COMBO_BOX (combo_box), "+3");
+	gtk_combo_box_append_text (GTK_COMBO_BOX (combo_box), "+4");
 
-	for (i = 0; i < GTK_HTML_FONT_STYLE_SIZE_MAX; i++) {
-		GtkWidget *menu_item;
+	gtk_combo_box_set_active (GTK_COMBO_BOX (combo_box), 2);
 
-		size [0] = (i>1) ? '+' : '-';
-		size [1] = '0' + ((i>1) ? i - 2 : 2 - i);
+	g_signal_connect (
+		combo_box, "changed",
+		G_CALLBACK (active_font_size_changed), cd);
 
-		menu_item = gtk_menu_item_new_with_label (size);
-		gtk_widget_show (menu_item);
+	g_signal_connect (
+		cd->html, "insertion_font_style_changed",
+		G_CALLBACK (font_size_changed), cd);
 
-		gtk_menu_shell_append (GTK_MENU_SHELL (menu), menu_item);
+	gtk_widget_show (combo_box);
 
-		g_object_set_data (G_OBJECT (menu_item), "size",
-				     GINT_TO_POINTER (i));
-		g_signal_connect (menu_item, "activate", G_CALLBACK (set_font_size), cd);
-	}
-
-	gtk_option_menu_set_menu (GTK_OPTION_MENU (option_menu), menu);
-	gtk_option_menu_set_history (GTK_OPTION_MENU (option_menu), 2);
-
-	g_signal_connect (cd->html, "insertion_font_style_changed", G_CALLBACK (font_size_changed), cd);
-
-	gtk_widget_show (option_menu);
-
-	return option_menu;
+	return combo_box;
 }
 
 static void
@@ -524,11 +410,14 @@ enum EditorAlignmentButtons {
 };
 static GnomeUIInfo editor_toolbar_alignment_group[] = {
 	{ GNOME_APP_UI_ITEM, N_("Left align"), N_("Left justifies the paragraphs"),
-	  editor_toolbar_left_align_cb, NULL, NULL, GNOME_APP_PIXMAP_FILENAME },
+	  editor_toolbar_left_align_cb, NULL, NULL, GNOME_APP_PIXMAP_STOCK,
+	  GTK_STOCK_JUSTIFY_LEFT },
 	{ GNOME_APP_UI_ITEM, N_("Center"), N_("Center justifies the paragraphs"),
-	  editor_toolbar_center_cb, NULL, NULL, GNOME_APP_PIXMAP_FILENAME },
+	  editor_toolbar_center_cb, NULL, NULL, GNOME_APP_PIXMAP_STOCK,
+	  GTK_STOCK_JUSTIFY_CENTER },
 	{ GNOME_APP_UI_ITEM, N_("Right align"), N_("Right justifies the paragraphs"),
-	  editor_toolbar_right_align_cb, NULL, NULL, GNOME_APP_PIXMAP_FILENAME },
+	  editor_toolbar_right_align_cb, NULL, NULL, GNOME_APP_PIXMAP_STOCK,
+	  GTK_STOCK_JUSTIFY_RIGHT },
 	GNOMEUIINFO_END
 };
 
@@ -550,13 +439,17 @@ static GnomeUIInfo editor_toolbar_style_uiinfo[] = {
 	{ GNOME_APP_UI_TOGGLEITEM, N_("Typewriter"), N_("Toggle typewriter font style"),
 	  editor_toolbar_tt_cb, NULL, NULL, GNOME_APP_PIXMAP_FILENAME },
 	{ GNOME_APP_UI_TOGGLEITEM, N_("Bold"), N_("Makes the text bold"),
-	  editor_toolbar_bold_cb, NULL, NULL, GNOME_APP_PIXMAP_FILENAME },
+	  editor_toolbar_bold_cb, NULL, NULL, GNOME_APP_PIXMAP_STOCK,
+	  GTK_STOCK_BOLD },
 	{ GNOME_APP_UI_TOGGLEITEM, N_("Italic"), N_("Makes the text italic"),
-	  editor_toolbar_italic_cb, NULL, NULL, GNOME_APP_PIXMAP_FILENAME },
+	  editor_toolbar_italic_cb, NULL, NULL, GNOME_APP_PIXMAP_STOCK,
+	  GTK_STOCK_ITALIC },
 	{ GNOME_APP_UI_TOGGLEITEM, N_("Underline"), N_("Underlines the text"),
-	  editor_toolbar_underline_cb, NULL, NULL, GNOME_APP_PIXMAP_FILENAME },
+	  editor_toolbar_underline_cb, NULL, NULL, GNOME_APP_PIXMAP_STOCK,
+	  GTK_STOCK_UNDERLINE },
 	{ GNOME_APP_UI_TOGGLEITEM, N_("Strikeout"), N_("Strikes out the text"),
-	  editor_toolbar_strikeout_cb, NULL, NULL, GNOME_APP_PIXMAP_FILENAME },
+	  editor_toolbar_strikeout_cb, NULL, NULL, GNOME_APP_PIXMAP_STOCK,
+	  GTK_STOCK_STRIKETHROUGH },
 
 	GNOMEUIINFO_SEPARATOR,
 
@@ -565,9 +458,11 @@ static GnomeUIInfo editor_toolbar_style_uiinfo[] = {
 	GNOMEUIINFO_SEPARATOR,
 
 	{ GNOME_APP_UI_ITEM, N_("Unindent"), N_("Indents the paragraphs less"),
-	  editor_toolbar_unindent_cb, NULL, NULL, GNOME_APP_PIXMAP_FILENAME },
+	  editor_toolbar_unindent_cb, NULL, NULL, GNOME_APP_PIXMAP_STOCK,
+	  GTK_STOCK_UNINDENT },
 	{ GNOME_APP_UI_ITEM, N_("Indent"), N_("Indents the paragraphs more"),
-	  editor_toolbar_indent_cb, NULL, NULL, GNOME_APP_PIXMAP_FILENAME },
+	  editor_toolbar_indent_cb, NULL, NULL, GNOME_APP_PIXMAP_STOCK,
+	  GTK_STOCK_INDENT },
 
 	GNOMEUIINFO_END
 };
@@ -597,24 +492,25 @@ indentation_changed (GtkWidget *w, guint level, GtkHTMLControlData *cd)
 static GtkWidget *
 create_style_toolbar (GtkHTMLControlData *cd)
 {
+	GtkIconInfo *icon_info;
 	GtkWidget *hbox;
 	gchar *domain;
-	gchar *filename;
 	
 	hbox = gtk_hbox_new (FALSE, 0);
 
 	cd->toolbar_style = gtk_toolbar_new ();
 	gtk_box_pack_start (GTK_BOX (hbox), cd->toolbar_style, TRUE, TRUE, 0);
 
-	cd->paragraph_option = setup_paragraph_style_option_menu (cd->html);
+	cd->paragraph_option = paragraph_style_combo_box_new (cd);
 	gtk_toolbar_prepend_space (GTK_TOOLBAR (cd->toolbar_style));
 	gtk_toolbar_prepend_widget (GTK_TOOLBAR (cd->toolbar_style),
 				    cd->paragraph_option,
 				    NULL, NULL);
 
+	cd->font_size_menu = setup_font_size_combo_box (cd);
 	gtk_toolbar_prepend_space (GTK_TOOLBAR (cd->toolbar_style));
 	gtk_toolbar_prepend_widget (GTK_TOOLBAR (cd->toolbar_style),
-				    setup_font_size_option_menu (cd),
+				    cd->font_size_menu,
 				    NULL, NULL);
 
 	/* 
@@ -624,21 +520,12 @@ create_style_toolbar (GtkHTMLControlData *cd)
 	domain = g_strdup (textdomain (NULL));
 	textdomain (GETTEXT_PACKAGE);
 	
-	filename = g_build_filename (GTKHTML_DATADIR, "icons", "font-tt-24.png", NULL);
-	editor_toolbar_style_uiinfo [EDITOR_TOOLBAR_TT].pixmap_info = filename;
-	editor_toolbar_style_uiinfo [EDITOR_TOOLBAR_BOLD].pixmap_info = gnome_icon_theme_lookup_icon (cd->icon_theme, "stock_text_bold", 24, NULL, NULL);
-	editor_toolbar_style_uiinfo [EDITOR_TOOLBAR_ITALIC].pixmap_info = gnome_icon_theme_lookup_icon (cd->icon_theme, "stock_text_italic", 24, NULL, NULL);
-	editor_toolbar_style_uiinfo [EDITOR_TOOLBAR_UNDERLINE].pixmap_info = gnome_icon_theme_lookup_icon (cd->icon_theme, "stock_text_underlined", 24, NULL, NULL);
-	editor_toolbar_style_uiinfo [EDITOR_TOOLBAR_STRIKEOUT].pixmap_info = gnome_icon_theme_lookup_icon (cd->icon_theme, "stock_text-strikethrough", 24, NULL, NULL);
-	editor_toolbar_style_uiinfo [EDITOR_TOOLBAR_UNINDENT].pixmap_info = gnome_icon_theme_lookup_icon (cd->icon_theme, "stock_text_unindent", 24, NULL, NULL);
-	editor_toolbar_style_uiinfo [EDITOR_TOOLBAR_INDENT].pixmap_info = gnome_icon_theme_lookup_icon (cd->icon_theme, "stock_text_indent", 24, NULL, NULL);
-
-	((GnomeUIInfo *) editor_toolbar_style_uiinfo [EDITOR_TOOLBAR_ALIGNMENT].moreinfo) [EDITOR_ALIGNMENT_LEFT].pixmap_info
-		= gnome_icon_theme_lookup_icon (cd->icon_theme, "stock_text_left", 24, NULL, NULL);
-	((GnomeUIInfo *) editor_toolbar_style_uiinfo [EDITOR_TOOLBAR_ALIGNMENT].moreinfo) [EDITOR_ALIGNMENT_CENTER].pixmap_info
-		= gnome_icon_theme_lookup_icon (cd->icon_theme, "stock_text_center", 24, NULL, NULL);
-	((GnomeUIInfo *) editor_toolbar_style_uiinfo [EDITOR_TOOLBAR_ALIGNMENT].moreinfo) [EDITOR_ALIGNMENT_RIGHT].pixmap_info
-		= gnome_icon_theme_lookup_icon (cd->icon_theme, "stock_text_right", 24, NULL, NULL);
+	icon_info = gtk_icon_theme_lookup_icon (
+		gtk_icon_theme_get_default (),
+		"stock_text-monospaced", 24, 0);
+	editor_toolbar_style_uiinfo [EDITOR_TOOLBAR_TT].pixmap_info =
+		g_strdup (gtk_icon_info_get_filename (icon_info));
+	gtk_icon_info_free (icon_info);
 
 	gnome_app_fill_toolbar_with_data (GTK_TOOLBAR (cd->toolbar_style), editor_toolbar_style_uiinfo, NULL, cd);
 
@@ -685,8 +572,6 @@ create_style_toolbar (GtkHTMLControlData *cd)
 	gtk_widget_show_all (hbox);
 
 	toolbar_update_format (cd);
-	GTK_WIDGET_UNSET_FLAGS (cd->toolbar_style, GTK_CAN_FOCUS);
-	gtk_container_forall (GTK_CONTAINER (cd->toolbar_style), unset_focus, NULL);
 
 	return hbox;
 }
@@ -734,10 +619,6 @@ toolbar_update_format (GtkHTMLControlData *cd)
 	if (cd->toolbar_style)
 		gtk_container_foreach (GTK_CONTAINER (cd->toolbar_style), 
 		toolbar_item_update_sensitivity, cd);
-
-	if (cd->paragraph_option)
-		paragraph_style_option_menu_set_mode (cd->paragraph_option, 
-						      cd->format_html);
 }
 
 
