@@ -22,8 +22,6 @@
 #ifndef _GTKHTML_PRIVATE_H
 #define _GTKHTML_PRIVATE_H
 
-#include <libgnomeprint/gnome-print.h>
-#include <libgnomeprint/gnome-print-job.h>
 #include <gtk/gtkimcontext.h>
 #include <gtk/gtkwidget.h>
 #include "gtkhtml-types.h"
@@ -47,9 +45,8 @@ struct _GtkHTMLPrivate {
 
 	GtkWidget *search_input_line;
 
-	GnomePrintJob *print_master;
-
 	guint notify_spell_id;
+	guint notify_monospace_font_id;
 
 	GtkIMContext *im_context;
 	gboolean need_im_reset;
@@ -93,4 +90,44 @@ void  gtk_html_im_reset                 (GtkHTML                *html);
 void  gtk_html_set_fonts                (GtkHTML                *html,
 					 HTMLPainter            *painter);
 
+gchar *gtk_html_filename_to_uri		(const gchar		*filename);
+gchar *gtk_html_filename_from_uri	(const gchar		*uri);
+
+#ifdef G_OS_WIN32
+
+const char *_get_icondir (void) G_GNUC_CONST;
+const char *_get_gtkhtml_datadir (void) G_GNUC_CONST;
+const char *_get_localedir (void) G_GNUC_CONST;
+const char *_get_glade_datadir (void) G_GNUC_CONST;
+const char *_get_prefix (void) G_GNUC_CONST;
+const char *_get_sysconfdir (void) G_GNUC_CONST;
+const char *_get_datadir (void) G_GNUC_CONST;
+const char *_get_libdir (void) G_GNUC_CONST;
+
+#undef ICONDIR
+#define ICONDIR _get_icondir ()
+
+#undef GTKHTML_DATADIR
+#define GTKHTML_DATADIR _get_gtkhtml_datadir ()
+
+#undef GNOMELOCALEDIR
+#define GNOMELOCALEDIR _get_localedir ()
+
+#undef GLADE_DATADIR
+#define GLADE_DATADIR _get_glade_datadir ()
+
+#undef PREFIX
+#define PREFIX _get_prefix ()
+
+#undef SYSCONFDIR
+#define SYSCONFDIR _get_sysconfdir ()
+
+#undef DATADIR
+#define DATADIR _get_datadir ()
+
+#undef LIBDIR
+#define LIBDIR _get_libdir ()
+
+#endif
+
 #endif /* _GTKHTML_PRIVATE_H */
