@@ -188,16 +188,17 @@ gtk_html_debug_dump_object (HTMLObject *obj,
 		g_free (sl_text);
 
 		width = 0;
-		for (cur = HTML_TEXT_SLAVE (obj)->glyph_items; cur; cur = cur->next) {
-			HTMLTextSlaveGlyphItem *sgi = (HTMLTextSlaveGlyphItem *) cur->data;
-			PangoItem *item = sgi->glyph_item.item;
-			PangoRectangle log_rect;
+		if (HTML_TEXT_SLAVE (obj)->glyph_items)
+			for (cur = HTML_TEXT_SLAVE (obj)->glyph_items; cur; cur = cur->next) {
+				HTMLTextSlaveGlyphItem *sgi = (HTMLTextSlaveGlyphItem *) cur->data;
+				PangoItem *item = sgi->glyph_item.item;
+				PangoRectangle log_rect;
 
-			pango_glyph_string_extents (sgi->glyph_item.glyphs, sgi->glyph_item.item->analysis.font, NULL, &log_rect);
-			g_print ("type: %d item level: %d offset: %d length: %d width: %d chars %d glyphs %d\n", sgi->type, item->analysis.level, item->offset, item->length, log_rect.width, item->num_chars, sgi->glyph_item.glyphs->num_glyphs);
-			width += log_rect.width;
+				pango_glyph_string_extents (sgi->glyph_item.glyphs, sgi->glyph_item.item->analysis.font, NULL, &log_rect);
+				g_print ("type: %d item level: %d offset: %d length: %d width: %d chars %d glyphs %d\n", sgi->type, item->analysis.level, item->offset, item->length, log_rect.width, item->num_chars, sgi->glyph_item.glyphs->num_glyphs);
+				width += log_rect.width;
 
-		}
+			}
 
 		g_print ("total width by glyph string extents (in engine units): %d\n", (int)(0.5 + width / PANGO_SCALE));
 
@@ -262,6 +263,8 @@ gtk_html_debug_dump_object (HTMLObject *obj,
 				g_print ("\n");
 			}
 		}
+		gtk_html_debug_list_links (text);
+		gtk_html_debug_list_text_attrs (text);
 		break;
 	}
 	case HTML_TYPE_CLUEV:
@@ -288,8 +291,6 @@ gtk_html_debug_dump_object (HTMLObject *obj,
 		g_print ("Location: %s\n", HTML_IMAGE (obj)->image_ptr->url);
 		break;
 	case HTML_TYPE_FRAMESET: {
-		gint i;
-
 		for (i = 0; i < HTML_FRAMESET (obj)->frames->len; i++)
 			gtk_html_debug_dump_tree (g_ptr_array_index (HTML_FRAMESET (obj)->frames, i), level + 1);
 		}
@@ -337,9 +338,7 @@ dump_object_simple (HTMLObject *obj,
 		g_print ("%s `%s'\n",
 			 html_type_name (HTML_OBJECT_TYPE (obj)),
 			 text->text);
-		g_print ("len %d bytes %d\n", text->text_len, text->text_bytes);
-		gtk_html_debug_list_links (text);
-		gtk_html_debug_list_text_attrs (text);
+/* 		g_print ("len %d bytes %d\n", text->text_len, text->text_bytes); */
 	} else if (HTML_OBJECT_TYPE (obj) == HTML_TYPE_TEXTSLAVE) {
 		HTMLTextSlave *slave = HTML_TEXT_SLAVE (obj);
 		gchar *text;
@@ -449,6 +448,8 @@ gtk_html_debug_list_attrs (PangoAttrList *attrs)
 		D_ATTR_TYPE (SCALE, "Scale");
 		g_print ("------------\n");
 	} while (pango_attr_iterator_next (iter));
+
+	pango_attr_iterator_destroy (iter);
 }
 
 void
